@@ -1,7 +1,7 @@
 #ifndef __EDG_WORKLOAD_LOGGING_COMMON_LB_GSS_H__
 #define __EDG_WORKLOAD_LOGGING_COMMON_LB_GSS_H__
 
-#ident "$Header: /cvs/jra1mw/org.glite.lbjp-common.gss/interface/glite_gss.h,v 1.8 2012/08/10 10:08:45 mvocu Exp $"
+#ident "$Header$"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -83,10 +83,15 @@ edg_wll_gss_finalize(void);
 int
 edg_wll_gss_acquire_cred(const char *cert_file,
 			 const char *key_file,
+			 const gss_cred_usage_t cred_usage,
 			 edg_wll_GssCred *cred,
 			 edg_wll_GssStatus* gss_code);
 
-#define edg_wll_gss_acquire_cred_gsi edg_wll_gss_acquire_cred
+int
+edg_wll_gss_acquire_cred_gsi(const char *cert_file,
+			     const char *key_file,
+			     edg_wll_GssCred *cred,
+			     edg_wll_GssStatus* gss_code);
 
 int
 edg_wll_gss_release_cred(edg_wll_GssCred *cred,
